#!/usr/bin/python
# -*- encoding=utf-8 -*-
from airflow import DAG
from datetime import datetime, timedelta
from airflow.contrib.hooks.ssh_hook import SSHHook
from airflow.contrib.operators.ssh_operator import SSHOperator
from airflow.sensors.external_task_sensor import ExternalTaskSensor
import json

from airflow.operators.email_operator import EmailOperator
from airflow.utils.trigger_rule import TriggerRule


sshHook = SSHHook(ssh_conn_id ='ssh_air')
default_args = {
'owner': 'info@idgvalue.com',
'email_on_failure': True,
'email_on_retry':True,
'start_date': datetime(2024, 1, 1),
'depends_on_past': False,
'retries': 6,
'retry_delay': timedelta(minutes=10),
}

dag = DAG('wf_dag_tk_api', default_args=default_args,
schedule_interval="0 0 * * *",
catchup=False,
dagrun_timeout=timedelta(minutes=160),
max_active_runs=3)

task_failed = EmailOperator (
    dag=dag,
    trigger_rule=TriggerRule.ONE_FAILED,
    task_id="task_failed",
    to=["info@idgvalue.com"],
    cc=[""],
    subject="tk_api_failed",
    html_content='<h3>您好，tk_api作业失败，请及时处理" </h3>')

customer_events_submit_form_4283 = SSHOperator(
ssh_hook=sshHook,
task_id='customer_events_submit_form_4283',
command='/data/airflow/etl/SA/run_sa.sh {{ ds_nodash }} {{ params.my_param }} >>/data/airflow/logs/run_psql_{{ds_nodash}}.log 2>&1 ',
params={'my_param':"S98_S_customer_events_submit_form"},
depends_on_past=False, 
retries=3, 
dag=dag)

customer_events_wechat_scan_2105 = SSHOperator(
ssh_hook=sshHook,
task_id='customer_events_wechat_scan_2105',
command='/data/airflow/etl/SA/run_sa.sh {{ ds_nodash }} {{ params.my_param }} >>/data/airflow/logs/run_psql_{{ds_nodash}}.log 2>&1 ',
params={'my_param':"S98_S_customer_events_wechat_scan"},
depends_on_past=False, 
retries=3, 
dag=dag)

customer_events_subscribe_5997 = SSHOperator(
ssh_hook=sshHook,
task_id='customer_events_subscribe_5997',
command='/data/airflow/etl/SA/run_sa.sh {{ ds_nodash }} {{ params.my_param }} >>/data/airflow/logs/run_psql_{{ds_nodash}}.log 2>&1 ',
params={'my_param':"S98_S_customer_events_subscribe"},
depends_on_past=False, 
retries=3, 
dag=dag)

customer_events_click_link_in_page_2034 = SSHOperator(
ssh_hook=sshHook,
task_id='customer_events_click_link_in_page_2034',
command='/data/airflow/etl/SA/run_sa.sh {{ ds_nodash }} {{ params.my_param }} >>/data/airflow/logs/run_psql_{{ds_nodash}}.log 2>&1 ',
params={'my_param':"S98_S_customer_events_click_link_in_page"},
depends_on_past=False, 
retries=3, 
dag=dag)

customer_events_open_app_5878 = SSHOperator(
ssh_hook=sshHook,
task_id='customer_events_open_app_5878',
command='/data/airflow/etl/SA/run_sa.sh {{ ds_nodash }} {{ params.my_param }} >>/data/airflow/logs/run_psql_{{ds_nodash}}.log 2>&1 ',
params={'my_param':"S98_S_customer_events_open_app"},
depends_on_past=False, 
retries=3, 
dag=dag)

customer_events_c_minipro_page_view_9309 = SSHOperator(
ssh_hook=sshHook,
task_id='customer_events_c_minipro_page_view_9309',
command='/data/airflow/etl/SA/run_sa.sh {{ ds_nodash }} {{ params.my_param }} >>/data/airflow/logs/run_psql_{{ds_nodash}}.log 2>&1 ',
params={'my_param':"S98_S_customer_events_c_minipro_page_view"},
depends_on_past=False, 
retries=3, 
dag=dag)

customer_events_add_user_9393 = SSHOperator(
ssh_hook=sshHook,
task_id='customer_events_add_user_9393',
command='/data/airflow/etl/SA/run_sa.sh {{ ds_nodash }} {{ params.my_param }} >>/data/airflow/logs/run_psql_{{ds_nodash}}.log 2>&1 ',
params={'my_param':"S98_S_customer_events_add_user"},
depends_on_past=False, 
retries=3, 
dag=dag)

custom_events_activity_submit_feign = SSHOperator(
ssh_hook=sshHook,
task_id='custom_events_activity_submit_feign',
command='python3 /data/airflow/etl/API/custom_events_activity_submit_feign.py',
depends_on_past=False, 
retries=3, 
dag=dag)

custom_events_activity_submit_load = SSHOperator(
ssh_hook=sshHook,
task_id='custom_events_activity_submit_load',
command='/data/airflow/etl/API/run_psql.sh {{ ds_nodash }} {{params.my_param }}',
params={'my_param':"custom_events_activity_submit_load"},
depends_on_past=False, 
retries=3, 
dag=dag)

custom_events_activity_submit_feign >> custom_events_activity_submit_load

custom_events_click_link_in_page_feign = SSHOperator(
ssh_hook=sshHook,
task_id='custom_events_click_link_in_page_feign',
command='python3 /data/airflow/etl/API/custom_events_click_link_in_page_feign.py',
depends_on_past=False, 
retries=3, 
dag=dag)

custom_events_click_link_in_page_load = SSHOperator(
ssh_hook=sshHook,
task_id='custom_events_click_link_in_page_load',
command='/data/airflow/etl/API/run_psql.sh {{ ds_nodash }} {{params.my_param }}',
params={'my_param':"custom_events_click_link_in_page_load"},
depends_on_past=False, 
retries=3, 
dag=dag)

custom_events_click_link_in_page_feign >> custom_events_click_link_in_page_load

custom_events_subscribe_feign = SSHOperator(
ssh_hook=sshHook,
task_id='custom_events_subscribe_feign',
command='python3 /data/airflow/etl/API/custom_events_subscribe_feign.py',
depends_on_past=False, 
retries=3, 
dag=dag)

custom_events_subscribe_load = SSHOperator(
ssh_hook=sshHook,
task_id='custom_events_subscribe_load',
command='/data/airflow/etl/API/run_psql.sh {{ ds_nodash }} {{params.my_param }}',
params={'my_param':"custom_events_subscribe_load"},
depends_on_past=False, 
retries=3, 
dag=dag)

custom_events_subscribe_feign >> custom_events_subscribe_load

custom_events_wechat_scan_feign = SSHOperator(
ssh_hook=sshHook,
task_id='custom_events_wechat_scan_feign',
command='python3 /data/airflow/etl/API/custom_events_wechat_scan_feign.py',
depends_on_past=False, 
retries=3, 
dag=dag)

custom_events_wechat_scan_load = SSHOperator(
ssh_hook=sshHook,
task_id='custom_events_wechat_scan_load',
command='/data/airflow/etl/API/run_psql.sh {{ ds_nodash }} {{params.my_param }}',
params={'my_param':"custom_events_wechat_scan_load"},
depends_on_past=False, 
retries=3, 
dag=dag)

custom_events_wechat_scan_feign >> custom_events_wechat_scan_load

custom_events_submit_form_feign = SSHOperator(
ssh_hook=sshHook,
task_id='custom_events_submit_form_feign',
command='python3 /data/airflow/etl/API/custom_events_submit_form_feign.py',
depends_on_past=False, 
retries=3, 
dag=dag)

custom_events_submit_form_load = SSHOperator(
ssh_hook=sshHook,
task_id='custom_events_submit_form_load',
command='/data/airflow/etl/API/run_psql.sh {{ ds_nodash }} {{params.my_param }}',
params={'my_param':"custom_events_submit_form_load"},
depends_on_past=False, 
retries=3, 
dag=dag)

custom_events_submit_form_feign >> custom_events_submit_form_load

custom_events_open_app_feign = SSHOperator(
ssh_hook=sshHook,
task_id='custom_events_open_app_feign',
command='python3 /data/airflow/etl/API/custom_events_open_app_feign.py',
depends_on_past=False, 
retries=3, 
dag=dag)

custom_events_open_app_load = SSHOperator(
ssh_hook=sshHook,
task_id='custom_events_open_app_load',
command='/data/airflow/etl/API/run_psql.sh {{ ds_nodash }} {{params.my_param }}',
params={'my_param':"custom_events_open_app_load"},
depends_on_past=False, 
retries=3, 
dag=dag)

custom_events_open_app_feign >> custom_events_open_app_load

custom_events_c_minipro_page_view_feign = SSHOperator(
ssh_hook=sshHook,
task_id='custom_events_c_minipro_page_view_feign',
command='python3 /data/airflow/etl/API/custom_events_c_minipro_page_view_feign.py',
depends_on_past=False, 
retries=3, 
dag=dag)

custom_events_c_minipro_page_view_load = SSHOperator(
ssh_hook=sshHook,
task_id='custom_events_c_minipro_page_view_load',
command='/data/airflow/etl/API/run_psql.sh {{ ds_nodash }} {{params.my_param }}',
params={'my_param':"custom_events_c_minipro_page_view_load"},
depends_on_past=False, 
retries=3, 
dag=dag)

custom_events_c_minipro_page_view_feign >> custom_events_c_minipro_page_view_load

custom_events_cp_employee_tools_huiju_event_add_feign = SSHOperator(
ssh_hook=sshHook,
task_id='custom_events_cp_employee_tools_huiju_event_add_feign',
command='python3 /data/airflow/etl/API/custom_events_cp_employee_tools_huiju_event_add_feign.py',
depends_on_past=False, 
retries=3, 
dag=dag)

custom_events_cp_employee_tools_huiju_event_add_load = SSHOperator(
ssh_hook=sshHook,
task_id='custom_events_cp_employee_tools_huiju_event_add_load',
command='/data/airflow/etl/API/run_psql.sh {{ ds_nodash }} {{params.my_param }}',
params={'my_param':"custom_events_cp_employee_tools_huiju_event_add_load"},
depends_on_past=False, 
retries=3, 
dag=dag)

custom_events_cp_employee_tools_huiju_event_add_feign >> custom_events_cp_employee_tools_huiju_event_add_load

custom_events_activity_submit_1455 = SSHOperator(
ssh_hook=sshHook,
task_id='custom_events_activity_submit_1455',
command='/data/airflow/etl/SA/run_sa.sh {{ ds_nodash }} {{ params.my_param }} >>/data/airflow/logs/run_psql_{{ds_nodash}}.log 2>&1 ',
params={'my_param':"S98_S_custom_events_activity_submit"},
depends_on_past=False, 
retries=3, 
dag=dag)

custom_events_click_link_in_page_load >> customer_events_click_link_in_page_2034
custom_events_subscribe_load >> customer_events_subscribe_5997
custom_events_wechat_scan_load >> customer_events_wechat_scan_2105
custom_events_c_minipro_page_view_load >> customer_events_c_minipro_page_view_9309
custom_events_submit_form_load >> customer_events_submit_form_4283
custom_events_open_app_load >> customer_events_open_app_5878
custom_events_cp_employee_tools_huiju_event_add_load >> customer_events_add_user_9393
custom_events_activity_submit_load >> custom_events_activity_submit_1455
custom_events_activity_submit_1455 >> task_failed 
